@@ -60,10 +60,17 @@ class TokenValidator:
         'email',
     ]
 
-    def __init__(self, application_id: str, scope: str, token_issuer: str):
+    def __init__(
+        self,
+        application_id: str,
+        scope: str,
+        token_issuer: str,
+        verify_expiration_time: bool = True,
+    ):
         self._application_id = application_id
         self._scope = scope
         self._token_issuer = token_issuer
+        self._verify_expiration_time = verify_expiration_time
 
     def validate(self, access_token: str, public_key: str) -> Token:
         parse_result = parse('Bearer {}', access_token)
@@ -80,7 +87,7 @@ class TokenValidator:
                 algorithms=[header.get('alg'), ],
                 options={
                     'require': self._REQUIRED_CLAIMS,
-                    'verify_exp': True,
+                    'verify_exp': self._verify_expiration_time,
                     'verify_aud': True
                 },
                 audience=self._application_id,
